#[repr(u32)]pub enum ucl_type {
UCL_OBJECT = 0,
UCL_ARRAY = 1,
UCL_INT = 2,
UCL_FLOAT = 3,
UCL_STRING = 4,
UCL_BOOLEAN = 5,
UCL_TIME = 6,
UCL_USERDATA = 7,
UCL_NULL = 8,
}Expand description
#ucl_object_t may have one of specified types, some types are compatible with each other and some are not. For example, you can always convert #UCL_TIME to #UCL_FLOAT. Also you can convert #UCL_FLOAT to #UCL_INTEGER by loosing floating point. Every object may be converted to a string by #ucl_object_tostring_forced() function.
Variants
UCL_OBJECT = 0
< UCL object - key/value pairs
UCL_ARRAY = 1
< UCL array
UCL_INT = 2
< Integer number
UCL_FLOAT = 3
< Floating point number
UCL_STRING = 4
< Null terminated string
UCL_BOOLEAN = 5
< Boolean value
UCL_TIME = 6
< Time value (floating point number of seconds)
UCL_USERDATA = 7
< Opaque userdata pointer (may be used in macros)
UCL_NULL = 8
< Null value