pub unsafe extern "C" fn ucl_array_pop_first(
top: *mut ucl_object_t,
) -> *mut ucl_object_tExpand description
Removes the first element from the array top, returning the object that was
removed. This object is not released, caller must unref the returned object
when it is no longer needed.
@param top array ucl object
@return removed element or NULL if top is NULL or not an array