ucl_object_fromstring_common

Function ucl_object_fromstring_common 

pub unsafe extern "C" fn ucl_object_fromstring_common(
    str: *const c_char,
    len: usize,
    flags: ucl_string_flags,
) -> *mut ucl_object_t
Convert any string to an ucl object making the specified transformations @param str fixed size or NULL terminated string @param len length (if len is zero, than str is treated as NULL terminated) @param flags conversion flags @return new object