pub unsafe extern "C" fn ucl_object_validate_root(
schema: *const ucl_object_t,
obj: *const ucl_object_t,
root: *const ucl_object_t,
err: *mut ucl_schema_error,
) -> boolExpand description
Validate object obj using schema object schema and root schema at root.
@param schema schema object
@param obj object to validate
@param root root schema object
@param err error pointer, if this parameter is not NULL and error has been
occurred, then err is filled with the exact error definition.
@return true if obj is valid using schema