pub unsafe extern "C" fn ucl_parser_add_string(
parser: *mut ucl_parser,
data: *const c_char,
len: usize,
) -> boolExpand description
Load ucl object from a string
@param parser parser structure
@param data the pointer to the string
@param len the length of the string, if len is 0 then data must be zero-terminated string
@return true if string has been added and false in case of error