ucl_parser_insert_chunk

Function ucl_parser_insert_chunk 

pub unsafe extern "C" fn ucl_parser_insert_chunk(
    parser: *mut ucl_parser,
    data: *const c_uchar,
    len: usize,
) -> bool
Insert new chunk to a parser (must have previously processed data with an existing top object) @param parser parser structure @param data the pointer to the beginning of a chunk @param len the length of a chunk @return true if chunk has been added and false in case of error