ucl_set_include_path

Function ucl_set_include_path 

pub unsafe extern "C" fn ucl_set_include_path(
    parser: *mut ucl_parser,
    paths: *mut ucl_object_t,
) -> bool
Provide a UCL_ARRAY of paths to search for include files. The object is copied so caller must unref the object. @param parser parser structure @param paths UCL_ARRAY of paths to search @return true if the path search array was replaced in the parser