#[repr(transparent)]pub struct ucl_object_flags(pub u32);Expand description
Basic flags for an object
Tuple Fields
0: u32Implementations
Sourceimpl ucl_object_flags
impl ucl_object_flags
Sourcepub const UCL_OBJECT_ALLOCATED_KEY: ucl_object_flags
pub const UCL_OBJECT_ALLOCATED_KEY: ucl_object_flags
< An object has key allocated internally
Sourceimpl ucl_object_flags
impl ucl_object_flags
Sourcepub const UCL_OBJECT_ALLOCATED_VALUE: ucl_object_flags
pub const UCL_OBJECT_ALLOCATED_VALUE: ucl_object_flags
< An object has a string value allocated internally
Sourceimpl ucl_object_flags
impl ucl_object_flags
Sourcepub const UCL_OBJECT_NEED_KEY_ESCAPE: ucl_object_flags
pub const UCL_OBJECT_NEED_KEY_ESCAPE: ucl_object_flags
< The key of an object need to be escaped on output
Sourceimpl ucl_object_flags
impl ucl_object_flags
Sourcepub const UCL_OBJECT_EPHEMERAL: ucl_object_flags
pub const UCL_OBJECT_EPHEMERAL: ucl_object_flags
< Temporary object that does not need to be freed really
Sourceimpl ucl_object_flags
impl ucl_object_flags
Sourcepub const UCL_OBJECT_MULTILINE: ucl_object_flags
pub const UCL_OBJECT_MULTILINE: ucl_object_flags
< String should be displayed as multiline string
Sourceimpl ucl_object_flags
impl ucl_object_flags
Sourcepub const UCL_OBJECT_MULTIVALUE: ucl_object_flags
pub const UCL_OBJECT_MULTIVALUE: ucl_object_flags
< Object is a key with multiple values
Sourceimpl ucl_object_flags
impl ucl_object_flags
Sourcepub const UCL_OBJECT_INHERITED: ucl_object_flags
pub const UCL_OBJECT_INHERITED: ucl_object_flags
< Object has been inherited from another
Sourceimpl ucl_object_flags
impl ucl_object_flags
Sourcepub const UCL_OBJECT_BINARY: ucl_object_flags
pub const UCL_OBJECT_BINARY: ucl_object_flags
< Object contains raw binary data