#[repr(transparent)]pub struct ucl_parser_flags(pub u32);Expand description
These flags defines parser behaviour. If you specify #UCL_PARSER_ZEROCOPY you must ensure that the input memory is not freed if an object is in use. Moreover, if you want to use zero-terminated keys and string values then you should not use zero-copy mode, as in this case UCL still has to perform copying implicitly.
Tuple Fields
0: u32Implementations
Sourceimpl ucl_parser_flags
impl ucl_parser_flags
Sourcepub const UCL_PARSER_DEFAULT: ucl_parser_flags
pub const UCL_PARSER_DEFAULT: ucl_parser_flags
< No special flags
Sourceimpl ucl_parser_flags
impl ucl_parser_flags
Sourcepub const UCL_PARSER_KEY_LOWERCASE: ucl_parser_flags
pub const UCL_PARSER_KEY_LOWERCASE: ucl_parser_flags
< Convert all keys to lower case
Sourceimpl ucl_parser_flags
impl ucl_parser_flags
Sourcepub const UCL_PARSER_ZEROCOPY: ucl_parser_flags
pub const UCL_PARSER_ZEROCOPY: ucl_parser_flags
< Parse input in zero-copy mode if possible
Sourceimpl ucl_parser_flags
impl ucl_parser_flags
Sourcepub const UCL_PARSER_NO_TIME: ucl_parser_flags
pub const UCL_PARSER_NO_TIME: ucl_parser_flags
< Do not parse time and treat time values as strings
Sourceimpl ucl_parser_flags
impl ucl_parser_flags
Sourcepub const UCL_PARSER_SAVE_COMMENTS: ucl_parser_flags
pub const UCL_PARSER_SAVE_COMMENTS: ucl_parser_flags
Create explicit arrays instead of implicit ones
Sourceimpl ucl_parser_flags
impl ucl_parser_flags
Sourcepub const UCL_PARSER_DISABLE_MACRO: ucl_parser_flags
pub const UCL_PARSER_DISABLE_MACRO: ucl_parser_flags
Save comments in the parser context
Sourceimpl ucl_parser_flags
impl ucl_parser_flags
Sourcepub const UCL_PARSER_NO_FILEVARS: ucl_parser_flags
pub const UCL_PARSER_NO_FILEVARS: ucl_parser_flags
Treat macros as comments